# -*- coding: utf-8 -*-
# Name of current package.
# Import built-in modules

PACKAGE_NAME = "arthub_login_widgets"
ARTHUB_RESET_PASSWORD_WEB_URL = "https://arthub.qq.com/reset-password"
ARTHUB_SET_ACCOUNT_INFO_WEB_URL = "https://arthub.qq.com/regist/personal?accountName="
UI_TEXT_MAP = {
    "window_title": ["Log in to ArtHub", "登录 ArtHub"],
    "account_placeholder": ["Email/Phone", "邮箱/手机号"],
    "password_placeholder": ["Password", "密码"],
    "login_button": ["Log in", "登录"],
    "forgot_password_button": ["Forgot password", "忘记密码"],
}



# -*- coding: utf-8 -*-
"""Import Test."""

# Import future modules
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

# Import built-in modules
import importlib
import pkgutil

# Import local modules
import arthub_login_widgets


def test_imports():
    """Test import modules."""
    prefix = "{}.".format(arthub_login_widgets.__name__)
    iter_packages = pkgutil.walk_packages(
        arthub_login_widgets.__path__,  # noqa: WPS609
        prefix,
    )
    for _, name, _ in iter_packages:
        module_name = name if name.startswith(prefix) else prefix + name
        importlib.import_module(module_name)
